@@ -170,6 +170,8 @@ class JobBuilder():
         self.idds_job = False
         self.scripts_path = os.getcwd()
         self.search_points = None
+        self.summary_fname = kGridSiteMetadataFileName
+
         
     @staticmethod
     def get_scheduler(name, metric, mode, search_space = None, **args):
@@ -381,11 +383,10 @@ class JobBuilder():
 
         metadata = self.create_metadata(df)
         
-        metadata_path = self.get_metadata_path()
-        
+        summary_output_path = helper.pretty_path(self.summary_fname)
         # save metadata
-        with open(metadata_path,'w') as output:
-            print('INFO: Job metadata is saved at {}'.format(metadata_path))
+        with open(summary_output_path, 'w') as output:
+            print('INFO: Job metadata is saved at {}'.format(summary_output_path))
             json.dump(metadata, output, cls=helper.NpEncoder)
         
         # save idds output
@@ -398,18 +399,6 @@ class JobBuilder():
     def get_loggers(self):
         from ray.tune.logger import NoopLogger, MLFLowLogger
         return [NoopLogger, MLFLowLogger]
-        
-    
-    def get_metadata_path(self):
-        base_path = hpogrid.get_workdir()
-        """
-        if hpogrid.is_local_job():
-            project_path = helper.get_project_path(self.project_name)
-            if os.path.exists(project_path):
-                base_path = project_path
-        """
-        metadata_path = os.path.join(base_path, kGridSiteMetadataFileName)
-        return metadata_path
     
     @classmethod
     def from_input(cls, config_input: [Dict, str],
